@@ -1,6 +1,7 @@
 use crate::chia_error;
 use crate::coin::Coin;
 use crate::streamable::Streamable;
+use crate::streamable_struct;
 use chia_streamable_macro::Streamable;
 
 #[cfg(feature = "py-bindings")]
@@ -12,10 +13,8 @@ use chia_py_streamable_macro::PyStreamable;
 #[cfg(feature = "py-bindings")]
 use pyo3::prelude::*;
 
-#[cfg_attr(feature = "py-bindings", pyclass, derive(PyStreamable))]
-#[derive(Streamable, Hash, Debug, Clone, Eq, PartialEq)]
-pub struct CoinState {
+streamable_struct! (CoinState {
     coin: Coin,
     spent_height: Option<u32>,
     created_height: Option<u32>,
-}
+});
