@@ -4,5 +4,7 @@ pub mod conditions;
 pub mod flags;
 pub mod get_puzzle_and_solution;
 pub mod opcodes;
+pub mod run_block_generator;
+pub mod run_puzzle;
 mod sanitize_int;
 pub mod validation_error;
