@@ -1,10 +1,11 @@
 use super::adapt_response::eval_err_to_pyresult;
+use chia::allocator::make_allocator;
 use clvmr::allocator::{Allocator, NodePtr, SExp};
 use clvmr::chia_dialect::ChiaDialect;
 use clvmr::cost::Cost;
 use clvmr::reduction::Response;
 use clvmr::run_program::run_program;
-use clvmr::serialize::{node_from_bytes, serialized_length_from_bytes};
+use clvmr::serde::{node_from_bytes, serialized_length_from_bytes};
 use pyo3::prelude::*;
 use pyo3::types::{PyBytes, PyTuple};
 use std::rc::Rc;
@@ -72,7 +73,7 @@ pub fn run_chia_program(
     max_cost: Cost,
     flags: u32,
 ) -> PyResult<(Cost, LazyNode)> {
-    let mut allocator = Allocator::new();
+    let mut allocator = make_allocator(flags);
 
     let r: Response = (|| -> PyResult<Response> {
         let program = node_from_bytes(&mut allocator, program)?;
@@ -80,7 +81,7 @@ pub fn run_chia_program(
         let dialect = ChiaDialect::new(flags);
 
         Ok(py
-            .allow_threads(|| run_program(&mut allocator, &dialect, program, args, max_cost, None)))
+            .allow_threads(|| run_program(&mut allocator, &dialect, program, args, max_cost)))
     })()?;
     match r {
         Ok(reduction) => {
